@@ -31,7 +31,8 @@ class CustomerResource(BaseResource):
         response = super().get(self.resource, params.to_dict())
         if super().is_20x(response.status_code):
             data = response.json().get("data")
-            return UnitResponse[CustomerDTO](DtoDecoder.decode(data), None)
+            meta = response.json().get("meta")
+            return UnitResponse[CustomerDTO](DtoDecoder.decode(data), meta=meta)
         else:
             return UnitError.from_json_api(response.json())
 
